# generated from rosidl_generator_py/resource/_idl.py.em
# with input from control_msgs:msg/AdmittanceControllerState.idl
# generated code does not contain a copyright notice

# This is being done at the module level and not on the instance level to avoid looking
# for the same variable multiple times on each instance. This variable is not supposed to
# change during runtime so it makes sense to only look for it once.
from os import getenv

ros_python_check_fields = getenv('ROS_PYTHON_CHECK_FIELDS', default='')


# Import statements for member types

import builtins  # noqa: E402, I100

import rosidl_parser.definition  # noqa: E402, I100


class Metaclass_AdmittanceControllerState(type):
    """Metaclass of message 'AdmittanceControllerState'."""

    _CREATE_ROS_MESSAGE = None
    _CONVERT_FROM_PY = None
    _CONVERT_TO_PY = None
    _DESTROY_ROS_MESSAGE = None
    _TYPE_SUPPORT = None

    __constants = {
    }

    @classmethod
    def __import_type_support__(cls):
        try:
            from rosidl_generator_py import import_type_support
            module = import_type_support('control_msgs')
        except ImportError:
            import logging
            import traceback
            logger = logging.getLogger(
                'control_msgs.msg.AdmittanceControllerState')
            logger.debug(
                'Failed to import needed modules for type support:\n' +
                traceback.format_exc())
        else:
            cls._CREATE_ROS_MESSAGE = module.create_ros_message_msg__msg__admittance_controller_state
            cls._CONVERT_FROM_PY = module.convert_from_py_msg__msg__admittance_controller_state
            cls._CONVERT_TO_PY = module.convert_to_py_msg__msg__admittance_controller_state
            cls._TYPE_SUPPORT = module.type_support_msg__msg__admittance_controller_state
            cls._DESTROY_ROS_MESSAGE = module.destroy_ros_message_msg__msg__admittance_controller_state

            from geometry_msgs.msg import Quaternion
            if Quaternion.__class__._TYPE_SUPPORT is None:
                Quaternion.__class__.__import_type_support__()

            from geometry_msgs.msg import TransformStamped
            if TransformStamped.__class__._TYPE_SUPPORT is None:
                TransformStamped.__class__.__import_type_support__()

            from geometry_msgs.msg import TwistStamped
            if TwistStamped.__class__._TYPE_SUPPORT is None:
                TwistStamped.__class__.__import_type_support__()

            from geometry_msgs.msg import WrenchStamped
            if WrenchStamped.__class__._TYPE_SUPPORT is None:
                WrenchStamped.__class__.__import_type_support__()

            from sensor_msgs.msg import JointState
            if JointState.__class__._TYPE_SUPPORT is None:
                JointState.__class__.__import_type_support__()

            from std_msgs.msg import Float64MultiArray
            if Float64MultiArray.__class__._TYPE_SUPPORT is None:
                Float64MultiArray.__class__.__import_type_support__()

            from std_msgs.msg import Int8MultiArray
            if Int8MultiArray.__class__._TYPE_SUPPORT is None:
                Int8MultiArray.__class__.__import_type_support__()

            from std_msgs.msg import String
            if String.__class__._TYPE_SUPPORT is None:
                String.__class__.__import_type_support__()

    @classmethod
    def __prepare__(cls, name, bases, **kwargs):
        # list constant names here so that they appear in the help text of
        # the message class under "Data and other attributes defined here:"
        # as well as populate each message instance
        return {
        }


class AdmittanceControllerState(metaclass=Metaclass_AdmittanceControllerState):
    """Message class 'AdmittanceControllerState'."""

    __slots__ = [
        '_mass',
        '_damping',
        '_stiffness',
        '_rot_base_control',
        '_ref_trans_base_ft',
        '_selected_axes',
        '_ft_sensor_frame',
        '_admittance_position',
        '_admittance_acceleration',
        '_admittance_velocity',
        '_wrench_base',
        '_joint_state',
        '_check_fields',
    ]

    _fields_and_field_types = {
        'mass': 'std_msgs/Float64MultiArray',
        'damping': 'std_msgs/Float64MultiArray',
        'stiffness': 'std_msgs/Float64MultiArray',
        'rot_base_control': 'geometry_msgs/Quaternion',
        'ref_trans_base_ft': 'geometry_msgs/TransformStamped',
        'selected_axes': 'std_msgs/Int8MultiArray',
        'ft_sensor_frame': 'std_msgs/String',
        'admittance_position': 'geometry_msgs/TransformStamped',
        'admittance_acceleration': 'geometry_msgs/TwistStamped',
        'admittance_velocity': 'geometry_msgs/TwistStamped',
        'wrench_base': 'geometry_msgs/WrenchStamped',
        'joint_state': 'sensor_msgs/JointState',
    }

    # This attribute is used to store an rosidl_parser.definition variable
    # related to the data type of each of the components the message.
    SLOT_TYPES = (
        rosidl_parser.definition.NamespacedType(['std_msgs', 'msg'], 'Float64MultiArray'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['std_msgs', 'msg'], 'Float64MultiArray'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['std_msgs', 'msg'], 'Float64MultiArray'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['geometry_msgs', 'msg'], 'Quaternion'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['geometry_msgs', 'msg'], 'TransformStamped'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['std_msgs', 'msg'], 'Int8MultiArray'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['std_msgs', 'msg'], 'String'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['geometry_msgs', 'msg'], 'TransformStamped'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['geometry_msgs', 'msg'], 'TwistStamped'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['geometry_msgs', 'msg'], 'TwistStamped'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['geometry_msgs', 'msg'], 'WrenchStamped'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['sensor_msgs', 'msg'], 'JointState'),  # noqa: E501
    )

    def __init__(self, **kwargs):
        if 'check_fields' in kwargs:
            self._check_fields = kwargs['check_fields']
        else:
            self._check_fields = ros_python_check_fields == '1'
        if self._check_fields:
            assert all('_' + key in self.__slots__ for key in kwargs.keys()), \
                'Invalid arguments passed to constructor: %s' % \
                ', '.join(sorted(k for k in kwargs.keys() if '_' + k not in self.__slots__))
        from std_msgs.msg import Float64MultiArray
        self.mass = kwargs.get('mass', Float64MultiArray())
        from std_msgs.msg import Float64MultiArray
        self.damping = kwargs.get('damping', Float64MultiArray())
        from std_msgs.msg import Float64MultiArray
        self.stiffness = kwargs.get('stiffness', Float64MultiArray())
        from geometry_msgs.msg import Quaternion
        self.rot_base_control = kwargs.get('rot_base_control', Quaternion())
        from geometry_msgs.msg import TransformStamped
        self.ref_trans_base_ft = kwargs.get('ref_trans_base_ft', TransformStamped())
        from std_msgs.msg import Int8MultiArray
        self.selected_axes = kwargs.get('selected_axes', Int8MultiArray())
        from std_msgs.msg import String
        self.ft_sensor_frame = kwargs.get('ft_sensor_frame', String())
        from geometry_msgs.msg import TransformStamped
        self.admittance_position = kwargs.get('admittance_position', TransformStamped())
        from geometry_msgs.msg import TwistStamped
        self.admittance_acceleration = kwargs.get('admittance_acceleration', TwistStamped())
        from geometry_msgs.msg import TwistStamped
        self.admittance_velocity = kwargs.get('admittance_velocity', TwistStamped())
        from geometry_msgs.msg import WrenchStamped
        self.wrench_base = kwargs.get('wrench_base', WrenchStamped())
        from sensor_msgs.msg import JointState
        self.joint_state = kwargs.get('joint_state', JointState())

    def __repr__(self):
        typename = self.__class__.__module__.split('.')
        typename.pop()
        typename.append(self.__class__.__name__)
        args = []
        for s, t in zip(self.get_fields_and_field_types().keys(), self.SLOT_TYPES):
            field = getattr(self, s)
            fieldstr = repr(field)
            # We use Python array type for fields that can be directly stored
            # in them, and "normal" sequences for everything else.  If it is
            # a type that we store in an array, strip off the 'array' portion.
            if (
                isinstance(t, rosidl_parser.definition.AbstractSequence) and
                isinstance(t.value_type, rosidl_parser.definition.BasicType) and
                t.value_type.typename in ['float', 'double', 'int8', 'uint8', 'int16', 'uint16', 'int32', 'uint32', 'int64', 'uint64']
            ):
                if len(field) == 0:
                    fieldstr = '[]'
                else:
                    if self._check_fields:
                        assert fieldstr.startswith('array(')
                    prefix = "array('X', "
                    suffix = ')'
                    fieldstr = fieldstr[len(prefix):-len(suffix)]
            args.append(s + '=' + fieldstr)
        return '%s(%s)' % ('.'.join(typename), ', '.join(args))

    def __eq__(self, other):
        if not isinstance(other, self.__class__):
            return False
        if self.mass != other.mass:
            return False
        if self.damping != other.damping:
            return False
        if self.stiffness != other.stiffness:
            return False
        if self.rot_base_control != other.rot_base_control:
            return False
        if self.ref_trans_base_ft != other.ref_trans_base_ft:
            return False
        if self.selected_axes != other.selected_axes:
            return False
        if self.ft_sensor_frame != other.ft_sensor_frame:
            return False
        if self.admittance_position != other.admittance_position:
            return False
        if self.admittance_acceleration != other.admittance_acceleration:
            return False
        if self.admittance_velocity != other.admittance_velocity:
            return False
        if self.wrench_base != other.wrench_base:
            return False
        if self.joint_state != other.joint_state:
            return False
        return True

    @classmethod
    def get_fields_and_field_types(cls):
        from copy import copy
        return copy(cls._fields_and_field_types)

    @builtins.property
    def mass(self):
        """Message field 'mass'."""
        return self._mass

    @mass.setter
    def mass(self, value):
        if self._check_fields:
            from std_msgs.msg import Float64MultiArray
            assert \
                isinstance(value, Float64MultiArray), \
                "The 'mass' field must be a sub message of type 'Float64MultiArray'"
        self._mass = value

    @builtins.property
    def damping(self):
        """Message field 'damping'."""
        return self._damping

    @damping.setter
    def damping(self, value):
        if self._check_fields:
            from std_msgs.msg import Float64MultiArray
            assert \
                isinstance(value, Float64MultiArray), \
                "The 'damping' field must be a sub message of type 'Float64MultiArray'"
        self._damping = value

    @builtins.property
    def stiffness(self):
        """Message field 'stiffness'."""
        return self._stiffness

    @stiffness.setter
    def stiffness(self, value):
        if self._check_fields:
            from std_msgs.msg import Float64MultiArray
            assert \
                isinstance(value, Float64MultiArray), \
                "The 'stiffness' field must be a sub message of type 'Float64MultiArray'"
        self._stiffness = value

    @builtins.property
    def rot_base_control(self):
        """Message field 'rot_base_control'."""
        return self._rot_base_control

    @rot_base_control.setter
    def rot_base_control(self, value):
        if self._check_fields:
            from geometry_msgs.msg import Quaternion
            assert \
                isinstance(value, Quaternion), \
                "The 'rot_base_control' field must be a sub message of type 'Quaternion'"
        self._rot_base_control = value

    @builtins.property
    def ref_trans_base_ft(self):
        """Message field 'ref_trans_base_ft'."""
        return self._ref_trans_base_ft

    @ref_trans_base_ft.setter
    def ref_trans_base_ft(self, value):
        if self._check_fields:
            from geometry_msgs.msg import TransformStamped
            assert \
                isinstance(value, TransformStamped), \
                "The 'ref_trans_base_ft' field must be a sub message of type 'TransformStamped'"
        self._ref_trans_base_ft = value

    @builtins.property
    def selected_axes(self):
        """Message field 'selected_axes'."""
        return self._selected_axes

    @selected_axes.setter
    def selected_axes(self, value):
        if self._check_fields:
            from std_msgs.msg import Int8MultiArray
            assert \
                isinstance(value, Int8MultiArray), \
                "The 'selected_axes' field must be a sub message of type 'Int8MultiArray'"
        self._selected_axes = value

    @builtins.property
    def ft_sensor_frame(self):
        """Message field 'ft_sensor_frame'."""
        return self._ft_sensor_frame

    @ft_sensor_frame.setter
    def ft_sensor_frame(self, value):
        if self._check_fields:
            from std_msgs.msg import String
            assert \
                isinstance(value, String), \
                "The 'ft_sensor_frame' field must be a sub message of type 'String'"
        self._ft_sensor_frame = value

    @builtins.property
    def admittance_position(self):
        """Message field 'admittance_position'."""
        return self._admittance_position

    @admittance_position.setter
    def admittance_position(self, value):
        if self._check_fields:
            from geometry_msgs.msg import TransformStamped
            assert \
                isinstance(value, TransformStamped), \
                "The 'admittance_position' field must be a sub message of type 'TransformStamped'"
        self._admittance_position = value

    @builtins.property
    def admittance_acceleration(self):
        """Message field 'admittance_acceleration'."""
        return self._admittance_acceleration

    @admittance_acceleration.setter
    def admittance_acceleration(self, value):
        if self._check_fields:
            from geometry_msgs.msg import TwistStamped
            assert \
                isinstance(value, TwistStamped), \
                "The 'admittance_acceleration' field must be a sub message of type 'TwistStamped'"
        self._admittance_acceleration = value

    @builtins.property
    def admittance_velocity(self):
        """Message field 'admittance_velocity'."""
        return self._admittance_velocity

    @admittance_velocity.setter
    def admittance_velocity(self, value):
        if self._check_fields:
            from geometry_msgs.msg import TwistStamped
            assert \
                isinstance(value, TwistStamped), \
                "The 'admittance_velocity' field must be a sub message of type 'TwistStamped'"
        self._admittance_velocity = value

    @builtins.property
    def wrench_base(self):
        """Message field 'wrench_base'."""
        return self._wrench_base

    @wrench_base.setter
    def wrench_base(self, value):
        if self._check_fields:
            from geometry_msgs.msg import WrenchStamped
            assert \
                isinstance(value, WrenchStamped), \
                "The 'wrench_base' field must be a sub message of type 'WrenchStamped'"
        self._wrench_base = value

    @builtins.property
    def joint_state(self):
        """Message field 'joint_state'."""
        return self._joint_state

    @joint_state.setter
    def joint_state(self, value):
        if self._check_fields:
            from sensor_msgs.msg import JointState
            assert \
                isinstance(value, JointState), \
                "The 'joint_state' field must be a sub message of type 'JointState'"
        self._joint_state = value



# generated from rosidl_generator_py/resource/_idl.py.em
# with input from control_msgs:msg/JointTrajectoryControllerState.idl
# generated code does not contain a copyright notice

# This is being done at the module level and not on the instance level to avoid looking
# for the same variable multiple times on each instance. This variable is not supposed to
# change during runtime so it makes sense to only look for it once.
from os import getenv

ros_python_check_fields = getenv('ROS_PYTHON_CHECK_FIELDS', default='')


# Import statements for member types

import builtins  # noqa: E402, I100

import math  # noqa: E402, I100

import rosidl_parser.definition  # noqa: E402, I100


class Metaclass_JointTrajectoryControllerState(type):
    """Metaclass of message 'JointTrajectoryControllerState'."""

    _CREATE_ROS_MESSAGE = None
    _CONVERT_FROM_PY = None
    _CONVERT_TO_PY = None
    _DESTROY_ROS_MESSAGE = None
    _TYPE_SUPPORT = None

    __constants = {
    }

    @classmethod
    def __import_type_support__(cls):
        try:
            from rosidl_generator_py import import_type_support
            module = import_type_support('control_msgs')
        except ImportError:
            import logging
            import traceback
            logger = logging.getLogger(
                'control_msgs.msg.JointTrajectoryControllerState')
            logger.debug(
                'Failed to import needed modules for type support:\n' +
                traceback.format_exc())
        else:
            cls._CREATE_ROS_MESSAGE = module.create_ros_message_msg__msg__joint_trajectory_controller_state
            cls._CONVERT_FROM_PY = module.convert_from_py_msg__msg__joint_trajectory_controller_state
            cls._CONVERT_TO_PY = module.convert_to_py_msg__msg__joint_trajectory_controller_state
            cls._TYPE_SUPPORT = module.type_support_msg__msg__joint_trajectory_controller_state
            cls._DESTROY_ROS_MESSAGE = module.destroy_ros_message_msg__msg__joint_trajectory_controller_state

            from std_msgs.msg import Header
            if Header.__class__._TYPE_SUPPORT is None:
                Header.__class__.__import_type_support__()

            from trajectory_msgs.msg import JointTrajectoryPoint
            if JointTrajectoryPoint.__class__._TYPE_SUPPORT is None:
                JointTrajectoryPoint.__class__.__import_type_support__()

            from trajectory_msgs.msg import MultiDOFJointTrajectoryPoint
            if MultiDOFJointTrajectoryPoint.__class__._TYPE_SUPPORT is None:
                MultiDOFJointTrajectoryPoint.__class__.__import_type_support__()

    @classmethod
    def __prepare__(cls, name, bases, **kwargs):
        # list constant names here so that they appear in the help text of
        # the message class under "Data and other attributes defined here:"
        # as well as populate each message instance
        return {
        }


class JointTrajectoryControllerState(metaclass=Metaclass_JointTrajectoryControllerState):
    """Message class 'JointTrajectoryControllerState'."""

    __slots__ = [
        '_header',
        '_joint_names',
        '_reference',
        '_feedback',
        '_error',
        '_output',
        '_multi_dof_joint_names',
        '_multi_dof_reference',
        '_multi_dof_feedback',
        '_multi_dof_error',
        '_multi_dof_output',
        '_speed_scaling_factor',
        '_check_fields',
    ]

    _fields_and_field_types = {
        'header': 'std_msgs/Header',
        'joint_names': 'sequence<string>',
        'reference': 'trajectory_msgs/JointTrajectoryPoint',
        'feedback': 'trajectory_msgs/JointTrajectoryPoint',
        'error': 'trajectory_msgs/JointTrajectoryPoint',
        'output': 'trajectory_msgs/JointTrajectoryPoint',
        'multi_dof_joint_names': 'sequence<string>',
        'multi_dof_reference': 'trajectory_msgs/MultiDOFJointTrajectoryPoint',
        'multi_dof_feedback': 'trajectory_msgs/MultiDOFJointTrajectoryPoint',
        'multi_dof_error': 'trajectory_msgs/MultiDOFJointTrajectoryPoint',
        'multi_dof_output': 'trajectory_msgs/MultiDOFJointTrajectoryPoint',
        'speed_scaling_factor': 'double',
    }

    # This attribute is used to store an rosidl_parser.definition variable
    # related to the data type of each of the components the message.
    SLOT_TYPES = (
        rosidl_parser.definition.NamespacedType(['std_msgs', 'msg'], 'Header'),  # noqa: E501
        rosidl_parser.definition.UnboundedSequence(rosidl_parser.definition.UnboundedString()),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['trajectory_msgs', 'msg'], 'JointTrajectoryPoint'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['trajectory_msgs', 'msg'], 'JointTrajectoryPoint'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['trajectory_msgs', 'msg'], 'JointTrajectoryPoint'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['trajectory_msgs', 'msg'], 'JointTrajectoryPoint'),  # noqa: E501
        rosidl_parser.definition.UnboundedSequence(rosidl_parser.definition.UnboundedString()),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['trajectory_msgs', 'msg'], 'MultiDOFJointTrajectoryPoint'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['trajectory_msgs', 'msg'], 'MultiDOFJointTrajectoryPoint'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['trajectory_msgs', 'msg'], 'MultiDOFJointTrajectoryPoint'),  # noqa: E501
        rosidl_parser.definition.NamespacedType(['trajectory_msgs', 'msg'], 'MultiDOFJointTrajectoryPoint'),  # noqa: E501
        rosidl_parser.definition.BasicType('double'),  # noqa: E501
    )

    def __init__(self, **kwargs):
        if 'check_fields' in kwargs:
            self._check_fields = kwargs['check_fields']
        else:
            self._check_fields = ros_python_check_fields == '1'
        if self._check_fields:
            assert all('_' + key in self.__slots__ for key in kwargs.keys()), \
                'Invalid arguments passed to constructor: %s' % \
                ', '.join(sorted(k for k in kwargs.keys() if '_' + k not in self.__slots__))
        from std_msgs.msg import Header
        self.header = kwargs.get('header', Header())
        self.joint_names = kwargs.get('joint_names', [])
        from trajectory_msgs.msg import JointTrajectoryPoint
        self.reference = kwargs.get('reference', JointTrajectoryPoint())
        from trajectory_msgs.msg import JointTrajectoryPoint
        self.feedback = kwargs.get('feedback', JointTrajectoryPoint())
        from trajectory_msgs.msg import JointTrajectoryPoint
        self.error = kwargs.get('error', JointTrajectoryPoint())
        from trajectory_msgs.msg import JointTrajectoryPoint
        self.output = kwargs.get('output', JointTrajectoryPoint())
        self.multi_dof_joint_names = kwargs.get('multi_dof_joint_names', [])
        from trajectory_msgs.msg import MultiDOFJointTrajectoryPoint
        self.multi_dof_reference = kwargs.get('multi_dof_reference', MultiDOFJointTrajectoryPoint())
        from trajectory_msgs.msg import MultiDOFJointTrajectoryPoint
        self.multi_dof_feedback = kwargs.get('multi_dof_feedback', MultiDOFJointTrajectoryPoint())
        from trajectory_msgs.msg import MultiDOFJointTrajectoryPoint
        self.multi_dof_error = kwargs.get('multi_dof_error', MultiDOFJointTrajectoryPoint())
        from trajectory_msgs.msg import MultiDOFJointTrajectoryPoint
        self.multi_dof_output = kwargs.get('multi_dof_output', MultiDOFJointTrajectoryPoint())
        self.speed_scaling_factor = kwargs.get('speed_scaling_factor', float())

    def __repr__(self):
        typename = self.__class__.__module__.split('.')
        typename.pop()
        typename.append(self.__class__.__name__)
        args = []
        for s, t in zip(self.get_fields_and_field_types().keys(), self.SLOT_TYPES):
            field = getattr(self, s)
            fieldstr = repr(field)
            # We use Python array type for fields that can be directly stored
            # in them, and "normal" sequences for everything else.  If it is
            # a type that we store in an array, strip off the 'array' portion.
            if (
                isinstance(t, rosidl_parser.definition.AbstractSequence) and
                isinstance(t.value_type, rosidl_parser.definition.BasicType) and
                t.value_type.typename in ['float', 'double', 'int8', 'uint8', 'int16', 'uint16', 'int32', 'uint32', 'int64', 'uint64']
            ):
                if len(field) == 0:
                    fieldstr = '[]'
                else:
                    if self._check_fields:
                        assert fieldstr.startswith('array(')
                    prefix = "array('X', "
                    suffix = ')'
                    fieldstr = fieldstr[len(prefix):-len(suffix)]
            args.append(s + '=' + fieldstr)
        return '%s(%s)' % ('.'.join(typename), ', '.join(args))

    def __eq__(self, other):
        if not isinstance(other, self.__class__):
            return False
        if self.header != other.header:
            return False
        if self.joint_names != other.joint_names:
            return False
        if self.reference != other.reference:
            return False
        if self.feedback != other.feedback:
            return False
        if self.error != other.error:
            return False
        if self.output != other.output:
            return False
        if self.multi_dof_joint_names != other.multi_dof_joint_names:
            return False
        if self.multi_dof_reference != other.multi_dof_reference:
            return False
        if self.multi_dof_feedback != other.multi_dof_feedback:
            return False
        if self.multi_dof_error != other.multi_dof_error:
            return False
        if self.multi_dof_output != other.multi_dof_output:
            return False
        if self.speed_scaling_factor != other.speed_scaling_factor:
            return False
        return True

    @classmethod
    def get_fields_and_field_types(cls):
        from copy import copy
        return copy(cls._fields_and_field_types)

    @builtins.property
    def header(self):
        """Message field 'header'."""
        return self._header

    @header.setter
    def header(self, value):
        if self._check_fields:
            from std_msgs.msg import Header
            assert \
                isinstance(value, Header), \
                "The 'header' field must be a sub message of type 'Header'"
        self._header = value

    @builtins.property
    def joint_names(self):
        """Message field 'joint_names'."""
        return self._joint_names

    @joint_names.setter
    def joint_names(self, value):
        if self._check_fields:
            from collections.abc import Sequence
            from collections.abc import Set
            from collections import UserList
            from collections import UserString
            assert \
                ((isinstance(value, Sequence) or
                  isinstance(value, Set) or
                  isinstance(value, UserList)) and
                 not isinstance(value, str) and
                 not isinstance(value, UserString) and
                 all(isinstance(v, str) for v in value) and
                 True), \
                "The 'joint_names' field must be a set or sequence and each value of type 'str'"
        self._joint_names = value

    @builtins.property
    def reference(self):
        """Message field 'reference'."""
        return self._reference

    @reference.setter
    def reference(self, value):
        if self._check_fields:
            from trajectory_msgs.msg import JointTrajectoryPoint
            assert \
                isinstance(value, JointTrajectoryPoint), \
                "The 'reference' field must be a sub message of type 'JointTrajectoryPoint'"
        self._reference = value

    @builtins.property
    def feedback(self):
        """Message field 'feedback'."""
        return self._feedback

    @feedback.setter
    def feedback(self, value):
        if self._check_fields:
            from trajectory_msgs.msg import JointTrajectoryPoint
            assert \
                isinstance(value, JointTrajectoryPoint), \
                "The 'feedback' field must be a sub message of type 'JointTrajectoryPoint'"
        self._feedback = value

    @builtins.property
    def error(self):
        """Message field 'error'."""
        return self._error

    @error.setter
    def error(self, value):
        if self._check_fields:
            from trajectory_msgs.msg import JointTrajectoryPoint
            assert \
                isinstance(value, JointTrajectoryPoint), \
                "The 'error' field must be a sub message of type 'JointTrajectoryPoint'"
        self._error = value

    @builtins.property
    def output(self):
        """Message field 'output'."""
        return self._output

    @output.setter
    def output(self, value):
        if self._check_fields:
            from trajectory_msgs.msg import JointTrajectoryPoint
            assert \
                isinstance(value, JointTrajectoryPoint), \
                "The 'output' field must be a sub message of type 'JointTrajectoryPoint'"
        self._output = value

    @builtins.property
    def multi_dof_joint_names(self):
        """Message field 'multi_dof_joint_names'."""
        return self._multi_dof_joint_names

    @multi_dof_joint_names.setter
    def multi_dof_joint_names(self, value):
        if self._check_fields:
            from collections.abc import Sequence
            from collections.abc import Set
            from collections import UserList
            from collections import UserString
            assert \
                ((isinstance(value, Sequence) or
                  isinstance(value, Set) or
                  isinstance(value, UserList)) and
                 not isinstance(value, str) and
                 not isinstance(value, UserString) and
                 all(isinstance(v, str) for v in value) and
                 True), \
                "The 'multi_dof_joint_names' field must be a set or sequence and each value of type 'str'"
        self._multi_dof_joint_names = value

    @builtins.property
    def multi_dof_reference(self):
        """Message field 'multi_dof_reference'."""
        return self._multi_dof_reference

    @multi_dof_reference.setter
    def multi_dof_reference(self, value):
        if self._check_fields:
            from trajectory_msgs.msg import MultiDOFJointTrajectoryPoint
            assert \
                isinstance(value, MultiDOFJointTrajectoryPoint), \
                "The 'multi_dof_reference' field must be a sub message of type 'MultiDOFJointTrajectoryPoint'"
        self._multi_dof_reference = value

    @builtins.property
    def multi_dof_feedback(self):
        """Message field 'multi_dof_feedback'."""
        return self._multi_dof_feedback

    @multi_dof_feedback.setter
    def multi_dof_feedback(self, value):
        if self._check_fields:
            from trajectory_msgs.msg import MultiDOFJointTrajectoryPoint
            assert \
                isinstance(value, MultiDOFJointTrajectoryPoint), \
                "The 'multi_dof_feedback' field must be a sub message of type 'MultiDOFJointTrajectoryPoint'"
        self._multi_dof_feedback = value

    @builtins.property
    def multi_dof_error(self):
        """Message field 'multi_dof_error'."""
        return self._multi_dof_error

    @multi_dof_error.setter
    def multi_dof_error(self, value):
        if self._check_fields:
            from trajectory_msgs.msg import MultiDOFJointTrajectoryPoint
            assert \
                isinstance(value, MultiDOFJointTrajectoryPoint), \
                "The 'multi_dof_error' field must be a sub message of type 'MultiDOFJointTrajectoryPoint'"
        self._multi_dof_error = value

    @builtins.property
    def multi_dof_output(self):
        """Message field 'multi_dof_output'."""
        return self._multi_dof_output

    @multi_dof_output.setter
    def multi_dof_output(self, value):
        if self._check_fields:
            from trajectory_msgs.msg import MultiDOFJointTrajectoryPoint
            assert \
                isinstance(value, MultiDOFJointTrajectoryPoint), \
                "The 'multi_dof_output' field must be a sub message of type 'MultiDOFJointTrajectoryPoint'"
        self._multi_dof_output = value

    @builtins.property
    def speed_scaling_factor(self):
        """Message field 'speed_scaling_factor'."""
        return self._speed_scaling_factor

    @speed_scaling_factor.setter
    def speed_scaling_factor(self, value):
        if self._check_fields:
            assert \
                isinstance(value, float), \
                "The 'speed_scaling_factor' field must be of type 'float'"
            assert not (value < -1.7976931348623157e+308 or value > 1.7976931348623157e+308) or math.isinf(value), \
                "The 'speed_scaling_factor' field must be a double in [-1.7976931348623157e+308, 1.7976931348623157e+308]"
        self._speed_scaling_factor = value



# generated from rosidl_generator_py/resource/_idl.py.em
# with input from control_msgs:msg/MotionPrimitive.idl
# generated code does not contain a copyright notice

# This is being done at the module level and not on the instance level to avoid looking
# for the same variable multiple times on each instance. This variable is not supposed to
# change during runtime so it makes sense to only look for it once.
from os import getenv

ros_python_check_fields = getenv('ROS_PYTHON_CHECK_FIELDS', default='')


# Import statements for member types

# Member 'joint_positions'
import array  # noqa: E402, I100

import builtins  # noqa: E402, I100

import math  # noqa: E402, I100

import rosidl_parser.definition  # noqa: E402, I100


class Metaclass_MotionPrimitive(type):
    """Metaclass of message 'MotionPrimitive'."""

    _CREATE_ROS_MESSAGE = None
    _CONVERT_FROM_PY = None
    _CONVERT_TO_PY = None
    _DESTROY_ROS_MESSAGE = None
    _TYPE_SUPPORT = None

    __constants = {
        'UNKNOWN': -1,
        'LINEAR_JOINT': 0,
        'LINEAR_CARTESIAN': 50,
        'CIRCULAR_CARTESIAN': 51,
    }

    @classmethod
    def __import_type_support__(cls):
        try:
            from rosidl_generator_py import import_type_support
            module = import_type_support('control_msgs')
        except ImportError:
            import logging
            import traceback
            logger = logging.getLogger(
                'control_msgs.msg.MotionPrimitive')
            logger.debug(
                'Failed to import needed modules for type support:\n' +
                traceback.format_exc())
        else:
            cls._CREATE_ROS_MESSAGE = module.create_ros_message_msg__msg__motion_primitive
            cls._CONVERT_FROM_PY = module.convert_from_py_msg__msg__motion_primitive
            cls._CONVERT_TO_PY = module.convert_to_py_msg__msg__motion_primitive
            cls._TYPE_SUPPORT = module.type_support_msg__msg__motion_primitive
            cls._DESTROY_ROS_MESSAGE = module.destroy_ros_message_msg__msg__motion_primitive

            from control_msgs.msg import MotionArgument
            if MotionArgument.__class__._TYPE_SUPPORT is None:
                MotionArgument.__class__.__import_type_support__()

            from geometry_msgs.msg import PoseStamped
            if PoseStamped.__class__._TYPE_SUPPORT is None:
                PoseStamped.__class__.__import_type_support__()

    @classmethod
    def __prepare__(cls, name, bases, **kwargs):
        # list constant names here so that they appear in the help text of
        # the message class under "Data and other attributes defined here:"
        # as well as populate each message instance
        return {
            'UNKNOWN': cls.__constants['UNKNOWN'],
            'LINEAR_JOINT': cls.__constants['LINEAR_JOINT'],
            'LINEAR_CARTESIAN': cls.__constants['LINEAR_CARTESIAN'],
            'CIRCULAR_CARTESIAN': cls.__constants['CIRCULAR_CARTESIAN'],
            'TYPE__DEFAULT': -1,
        }

    @property
    def UNKNOWN(self):
        """Message constant 'UNKNOWN'."""
        return Metaclass_MotionPrimitive.__constants['UNKNOWN']

    @property
    def LINEAR_JOINT(self):
        """Message constant 'LINEAR_JOINT'."""
        return Metaclass_MotionPrimitive.__constants['LINEAR_JOINT']

    @property
    def LINEAR_CARTESIAN(self):
        """Message constant 'LINEAR_CARTESIAN'."""
        return Metaclass_MotionPrimitive.__constants['LINEAR_CARTESIAN']

    @property
    def CIRCULAR_CARTESIAN(self):
        """Message constant 'CIRCULAR_CARTESIAN'."""
        return Metaclass_MotionPrimitive.__constants['CIRCULAR_CARTESIAN']

    @property
    def TYPE__DEFAULT(cls):
        """Return default value for message field 'type'."""
        return -1


class MotionPrimitive(metaclass=Metaclass_MotionPrimitive):
    """
    Message class 'MotionPrimitive'.

    Constants:
      UNKNOWN
      LINEAR_JOINT
      LINEAR_CARTESIAN
      CIRCULAR_CARTESIAN
    """

    __slots__ = [
        '_type',
        '_blend_radius',
        '_additional_arguments',
        '_poses',
        '_joint_positions',
        '_check_fields',
    ]

    _fields_and_field_types = {
        'type': 'int8',
        'blend_radius': 'double',
        'additional_arguments': 'sequence<control_msgs/MotionArgument>',
        'poses': 'sequence<geometry_msgs/PoseStamped>',
        'joint_positions': 'sequence<double>',
    }

    # This attribute is used to store an rosidl_parser.definition variable
    # related to the data type of each of the components the message.
    SLOT_TYPES = (
        rosidl_parser.definition.BasicType('int8'),  # noqa: E501
        rosidl_parser.definition.BasicType('double'),  # noqa: E501
        rosidl_parser.definition.UnboundedSequence(rosidl_parser.definition.NamespacedType(['control_msgs', 'msg'], 'MotionArgument')),  # noqa: E501
        rosidl_parser.definition.UnboundedSequence(rosidl_parser.definition.NamespacedType(['geometry_msgs', 'msg'], 'PoseStamped')),  # noqa: E501
        rosidl_parser.definition.UnboundedSequence(rosidl_parser.definition.BasicType('double')),  # noqa: E501
    )

    def __init__(self, **kwargs):
        if 'check_fields' in kwargs:
            self._check_fields = kwargs['check_fields']
        else:
            self._check_fields = ros_python_check_fields == '1'
        if self._check_fields:
            assert all('_' + key in self.__slots__ for key in kwargs.keys()), \
                'Invalid arguments passed to constructor: %s' % \
                ', '.join(sorted(k for k in kwargs.keys() if '_' + k not in self.__slots__))
        self.type = kwargs.get(
            'type', MotionPrimitive.TYPE__DEFAULT)
        self.blend_radius = kwargs.get('blend_radius', float())
        self.additional_arguments = kwargs.get('additional_arguments', [])
        self.poses = kwargs.get('poses', [])
        self.joint_positions = array.array('d', kwargs.get('joint_positions', []))

    def __repr__(self):
        typename = self.__class__.__module__.split('.')
        typename.pop()
        typename.append(self.__class__.__name__)
        args = []
        for s, t in zip(self.get_fields_and_field_types().keys(), self.SLOT_TYPES):
            field = getattr(self, s)
            fieldstr = repr(field)
            # We use Python array type for fields that can be directly stored
            # in them, and "normal" sequences for everything else.  If it is
            # a type that we store in an array, strip off the 'array' portion.
            if (
                isinstance(t, rosidl_parser.definition.AbstractSequence) and
                isinstance(t.value_type, rosidl_parser.definition.BasicType) and
                t.value_type.typename in ['float', 'double', 'int8', 'uint8', 'int16', 'uint16', 'int32', 'uint32', 'int64', 'uint64']
            ):
                if len(field) == 0:
                    fieldstr = '[]'
                else:
                    if self._check_fields:
                        assert fieldstr.startswith('array(')
                    prefix = "array('X', "
                    suffix = ')'
                    fieldstr = fieldstr[len(prefix):-len(suffix)]
            args.append(s + '=' + fieldstr)
        return '%s(%s)' % ('.'.join(typename), ', '.join(args))

    def __eq__(self, other):
        if not isinstance(other, self.__class__):
            return False
        if self.type != other.type:
            return False
        if self.blend_radius != other.blend_radius:
            return False
        if self.additional_arguments != other.additional_arguments:
            return False
        if self.poses != other.poses:
            return False
        if self.joint_positions != other.joint_positions:
            return False
        return True

    @classmethod
    def get_fields_and_field_types(cls):
        from copy import copy
        return copy(cls._fields_and_field_types)

    @builtins.property  # noqa: A003
    def type(self):  # noqa: A003
        """Message field 'type'."""
        return self._type

    @type.setter  # noqa: A003
    def type(self, value):  # noqa: A003
        if self._check_fields:
            assert \
                isinstance(value, int), \
                "The 'type' field must be of type 'int'"
            assert value >= -128 and value < 128, \
                "The 'type' field must be an integer in [-128, 127]"
        self._type = value

    @builtins.property
    def blend_radius(self):
        """Message field 'blend_radius'."""
        return self._blend_radius

    @blend_radius.setter
    def blend_radius(self, value):
        if self._check_fields:
            assert \
                isinstance(value, float), \
                "The 'blend_radius' field must be of type 'float'"
            assert not (value < -1.7976931348623157e+308 or value > 1.7976931348623157e+308) or math.isinf(value), \
                "The 'blend_radius' field must be a double in [-1.7976931348623157e+308, 1.7976931348623157e+308]"
        self._blend_radius = value

    @builtins.property
    def additional_arguments(self):
        """Message field 'additional_arguments'."""
        return self._additional_arguments

    @additional_arguments.setter
    def additional_arguments(self, value):
        if self._check_fields:
            from control_msgs.msg import MotionArgument
            from collections.abc import Sequence
            from collections.abc import Set
            from collections import UserList
            from collections import UserString
            assert \
                ((isinstance(value, Sequence) or
                  isinstance(value, Set) or
                  isinstance(value, UserList)) and
                 not isinstance(value, str) and
                 not isinstance(value, UserString) and
                 all(isinstance(v, MotionArgument) for v in value) and
                 True), \
                "The 'additional_arguments' field must be a set or sequence and each value of type 'MotionArgument'"
        self._additional_arguments = value

    @builtins.property
    def poses(self):
        """Message field 'poses'."""
        return self._poses

    @poses.setter
    def poses(self, value):
        if self._check_fields:
            from geometry_msgs.msg import PoseStamped
            from collections.abc import Sequence
            from collections.abc import Set
            from collections import UserList
            from collections import UserString
            assert \
                ((isinstance(value, Sequence) or
                  isinstance(value, Set) or
                  isinstance(value, UserList)) and
                 not isinstance(value, str) and
                 not isinstance(value, UserString) and
                 all(isinstance(v, PoseStamped) for v in value) and
                 True), \
                "The 'poses' field must be a set or sequence and each value of type 'PoseStamped'"
        self._poses = value

    @builtins.property
    def joint_positions(self):
        """Message field 'joint_positions'."""
        return self._joint_positions

    @joint_positions.setter
    def joint_positions(self, value):
        if self._check_fields:
            if isinstance(value, array.array):
                assert value.typecode == 'd', \
                    "The 'joint_positions' array.array() must have the type code of 'd'"
                self._joint_positions = value
                return
            from collections.abc import Sequence
            from collections.abc import Set
            from collections import UserList
            from collections import UserString
            assert \
                ((isinstance(value, Sequence) or
                  isinstance(value, Set) or
                  isinstance(value, UserList)) and
                 not isinstance(value, str) and
                 not isinstance(value, UserString) and
                 all(isinstance(v, float) for v in value) and
                 all(not (val < -1.7976931348623157e+308 or val > 1.7976931348623157e+308) or math.isinf(val) for val in value)), \
                "The 'joint_positions' field must be a set or sequence and each value of type 'float' and each double in [-179769313486231570814527423731704356798070567525844996598917476803157260780028538760589558632766878171540458953514382464234321326889464182768467546703537516986049910576551282076245490090389328944075868508455133942304583236903222948165808559332123348274797826204144723168738177180919299881250404026184124858368.000000, 179769313486231570814527423731704356798070567525844996598917476803157260780028538760589558632766878171540458953514382464234321326889464182768467546703537516986049910576551282076245490090389328944075868508455133942304583236903222948165808559332123348274797826204144723168738177180919299881250404026184124858368.000000]"
        self._joint_positions = array.array('d', value)



from control_msgs.srv._query_calibration_state import QueryCalibrationState  # noqa: F401
from control_msgs.srv._query_calibration_state import QueryCalibrationState_Event  # noqa: F401
from control_msgs.srv._query_calibration_state import QueryCalibrationState_Request  # noqa: F401
from control_msgs.srv._query_calibration_state import QueryCalibrationState_Response  # noqa: F401
from control_msgs.srv._query_trajectory_state import QueryTrajectoryState  # noqa: F401
from control_msgs.srv._query_trajectory_state import QueryTrajectoryState_Event  # noqa: F401
from control_msgs.srv._query_trajectory_state import QueryTrajectoryState_Request  # noqa: F401
from control_msgs.srv._query_trajectory_state import QueryTrajectoryState_Response  # noqa: F401
from control_msgs.srv._set_odometry import SetOdometry  # noqa: F401
from control_msgs.srv._set_odometry import SetOdometry_Event  # noqa: F401
from control_msgs.srv._set_odometry import SetOdometry_Request  # noqa: F401
from control_msgs.srv._set_odometry import SetOdometry_Response  # noqa: F401



# generated from rosidl_generator_py/resource/_idl.py.em
# with input from control_msgs:msg/InterfaceValue.idl
# generated code does not contain a copyright notice

# This is being done at the module level and not on the instance level to avoid looking
# for the same variable multiple times on each instance. This variable is not supposed to
# change during runtime so it makes sense to only look for it once.
from os import getenv

ros_python_check_fields = getenv('ROS_PYTHON_CHECK_FIELDS', default='')


# Import statements for member types

# Member 'values'
import array  # noqa: E402, I100

import builtins  # noqa: E402, I100

import math  # noqa: E402, I100

import rosidl_parser.definition  # noqa: E402, I100


class Metaclass_InterfaceValue(type):
    """Metaclass of message 'InterfaceValue'."""

    _CREATE_ROS_MESSAGE = None
    _CONVERT_FROM_PY = None
    _CONVERT_TO_PY = None
    _DESTROY_ROS_MESSAGE = None
    _TYPE_SUPPORT = None

    __constants = {
    }

    @classmethod
    def __import_type_support__(cls):
        try:
            from rosidl_generator_py import import_type_support
            module = import_type_support('control_msgs')
        except ImportError:
            import logging
            import traceback
            logger = logging.getLogger(
                'control_msgs.msg.InterfaceValue')
            logger.debug(
                'Failed to import needed modules for type support:\n' +
                traceback.format_exc())
        else:
            cls._CREATE_ROS_MESSAGE = module.create_ros_message_msg__msg__interface_value
            cls._CONVERT_FROM_PY = module.convert_from_py_msg__msg__interface_value
            cls._CONVERT_TO_PY = module.convert_to_py_msg__msg__interface_value
            cls._TYPE_SUPPORT = module.type_support_msg__msg__interface_value
            cls._DESTROY_ROS_MESSAGE = module.destroy_ros_message_msg__msg__interface_value

    @classmethod
    def __prepare__(cls, name, bases, **kwargs):
        # list constant names here so that they appear in the help text of
        # the message class under "Data and other attributes defined here:"
        # as well as populate each message instance
        return {
        }


class InterfaceValue(metaclass=Metaclass_InterfaceValue):
    """Message class 'InterfaceValue'."""

    __slots__ = [
        '_interface_names',
        '_values',
        '_check_fields',
    ]

    _fields_and_field_types = {
        'interface_names': 'sequence<string>',
        'values': 'sequence<double>',
    }

    # This attribute is used to store an rosidl_parser.definition variable
    # related to the data type of each of the components the message.
    SLOT_TYPES = (
        rosidl_parser.definition.UnboundedSequence(rosidl_parser.definition.UnboundedString()),  # noqa: E501
        rosidl_parser.definition.UnboundedSequence(rosidl_parser.definition.BasicType('double')),  # noqa: E501
    )

    def __init__(self, **kwargs):
        if 'check_fields' in kwargs:
            self._check_fields = kwargs['check_fields']
        else:
            self._check_fields = ros_python_check_fields == '1'
        if self._check_fields:
            assert all('_' + key in self.__slots__ for key in kwargs.keys()), \
                'Invalid arguments passed to constructor: %s' % \
                ', '.join(sorted(k for k in kwargs.keys() if '_' + k not in self.__slots__))
        self.interface_names = kwargs.get('interface_names', [])
        self.values = array.array('d', kwargs.get('values', []))

    def __repr__(self):
        typename = self.__class__.__module__.split('.')
        typename.pop()
        typename.append(self.__class__.__name__)
        args = []
        for s, t in zip(self.get_fields_and_field_types().keys(), self.SLOT_TYPES):
            field = getattr(self, s)
            fieldstr = repr(field)
            # We use Python array type for fields that can be directly stored
            # in them, and "normal" sequences for everything else.  If it is
            # a type that we store in an array, strip off the 'array' portion.
            if (
                isinstance(t, rosidl_parser.definition.AbstractSequence) and
                isinstance(t.value_type, rosidl_parser.definition.BasicType) and
                t.value_type.typename in ['float', 'double', 'int8', 'uint8', 'int16', 'uint16', 'int32', 'uint32', 'int64', 'uint64']
            ):
                if len(field) == 0:
                    fieldstr = '[]'
                else:
                    if self._check_fields:
                        assert fieldstr.startswith('array(')
                    prefix = "array('X', "
                    suffix = ')'
                    fieldstr = fieldstr[len(prefix):-len(suffix)]
            args.append(s + '=' + fieldstr)
        return '%s(%s)' % ('.'.join(typename), ', '.join(args))

    def __eq__(self, other):
        if not isinstance(other, self.__class__):
            return False
        if self.interface_names != other.interface_names:
            return False
        if self.values != other.values:
            return False
        return True

    @classmethod
    def get_fields_and_field_types(cls):
        from copy import copy
        return copy(cls._fields_and_field_types)

    @builtins.property
    def interface_names(self):
        """Message field 'interface_names'."""
        return self._interface_names

    @interface_names.setter
    def interface_names(self, value):
        if self._check_fields:
            from collections.abc import Sequence
            from collections.abc import Set
            from collections import UserList
            from collections import UserString
            assert \
                ((isinstance(value, Sequence) or
                  isinstance(value, Set) or
                  isinstance(value, UserList)) and
                 not isinstance(value, str) and
                 not isinstance(value, UserString) and
                 all(isinstance(v, str) for v in value) and
                 True), \
                "The 'interface_names' field must be a set or sequence and each value of type 'str'"
        self._interface_names = value

    @builtins.property
    def values(self):
        """Message field 'values'."""
        return self._values

    @values.setter
    def values(self, value):
        if self._check_fields:
            if isinstance(value, array.array):
                assert value.typecode == 'd', \
                    "The 'values' array.array() must have the type code of 'd'"
                self._values = value
                return
            from collections.abc import Sequence
            from collections.abc import Set
            from collections import UserList
            from collections import UserString
            assert \
                ((isinstance(value, Sequence) or
                  isinstance(value, Set) or
                  isinstance(value, UserList)) and
                 not isinstance(value, str) and
                 not isinstance(value, UserString) and
                 all(isinstance(v, float) for v in value) and
                 all(not (val < -1.7976931348623157e+308 or val > 1.7976931348623157e+308) or math.isinf(val) for val in value)), \
                "The 'values' field must be a set or sequence and each value of type 'float' and each double in [-179769313486231570814527423731704356798070567525844996598917476803157260780028538760589558632766878171540458953514382464234321326889464182768467546703537516986049910576551282076245490090389328944075868508455133942304583236903222948165808559332123348274797826204144723168738177180919299881250404026184124858368.000000, 179769313486231570814527423731704356798070567525844996598917476803157260780028538760589558632766878171540458953514382464234321326889464182768467546703537516986049910576551282076245490090389328944075868508455133942304583236903222948165808559332123348274797826204144723168738177180919299881250404026184124858368.000000]"
        self._values = array.array('d', value)



from control_msgs.action._execute_motion_primitive_sequence import ExecuteMotionPrimitiveSequence  # noqa: F401
from control_msgs.action._execute_motion_primitive_sequence import ExecuteMotionPrimitiveSequence_GetResult_Event  # noqa: F401
from control_msgs.action._execute_motion_primitive_sequence import ExecuteMotionPrimitiveSequence_GetResult_Request  # noqa: F401
from control_msgs.action._execute_motion_primitive_sequence import ExecuteMotionPrimitiveSequence_GetResult_Response  # noqa: F401
from control_msgs.action._execute_motion_primitive_sequence import ExecuteMotionPrimitiveSequence_SendGoal_Event  # noqa: F401
from control_msgs.action._execute_motion_primitive_sequence import ExecuteMotionPrimitiveSequence_SendGoal_Request  # noqa: F401
from control_msgs.action._execute_motion_primitive_sequence import ExecuteMotionPrimitiveSequence_SendGoal_Response  # noqa: F401
from control_msgs.action._follow_joint_trajectory import FollowJointTrajectory  # noqa: F401
from control_msgs.action._follow_joint_trajectory import FollowJointTrajectory_GetResult_Event  # noqa: F401
from control_msgs.action._follow_joint_trajectory import FollowJointTrajectory_GetResult_Request  # noqa: F401
from control_msgs.action._follow_joint_trajectory import FollowJointTrajectory_GetResult_Response  # noqa: F401
from control_msgs.action._follow_joint_trajectory import FollowJointTrajectory_SendGoal_Event  # noqa: F401
from control_msgs.action._follow_joint_trajectory import FollowJointTrajectory_SendGoal_Request  # noqa: F401
from control_msgs.action._follow_joint_trajectory import FollowJointTrajectory_SendGoal_Response  # noqa: F401
from control_msgs.action._gripper_command import GripperCommand  # noqa: F401
from control_msgs.action._gripper_command import GripperCommand_GetResult_Event  # noqa: F401
from control_msgs.action._gripper_command import GripperCommand_GetResult_Request  # noqa: F401
from control_msgs.action._gripper_command import GripperCommand_GetResult_Response  # noqa: F401
from control_msgs.action._gripper_command import GripperCommand_SendGoal_Event  # noqa: F401
from control_msgs.action._gripper_command import GripperCommand_SendGoal_Request  # noqa: F401
from control_msgs.action._gripper_command import GripperCommand_SendGoal_Response  # noqa: F401
from control_msgs.action._joint_trajectory import JointTrajectory  # noqa: F401
from control_msgs.action._joint_trajectory import JointTrajectory_GetResult_Event  # noqa: F401
from control_msgs.action._joint_trajectory import JointTrajectory_GetResult_Request  # noqa: F401
from control_msgs.action._joint_trajectory import JointTrajectory_GetResult_Response  # noqa: F401
from control_msgs.action._joint_trajectory import JointTrajectory_SendGoal_Event  # noqa: F401
from control_msgs.action._joint_trajectory import JointTrajectory_SendGoal_Request  # noqa: F401
from control_msgs.action._joint_trajectory import JointTrajectory_SendGoal_Response  # noqa: F401
from control_msgs.action._parallel_gripper_command import ParallelGripperCommand  # noqa: F401
from control_msgs.action._parallel_gripper_command import ParallelGripperCommand_GetResult_Event  # noqa: F401
from control_msgs.action._parallel_gripper_command import ParallelGripperCommand_GetResult_Request  # noqa: F401
from control_msgs.action._parallel_gripper_command import ParallelGripperCommand_GetResult_Response  # noqa: F401
from control_msgs.action._parallel_gripper_command import ParallelGripperCommand_SendGoal_Event  # noqa: F401
from control_msgs.action._parallel_gripper_command import ParallelGripperCommand_SendGoal_Request  # noqa: F401
from control_msgs.action._parallel_gripper_command import ParallelGripperCommand_SendGoal_Response  # noqa: F401
from control_msgs.action._point_head import PointHead  # noqa: F401
from control_msgs.action._point_head import PointHead_GetResult_Event  # noqa: F401
from control_msgs.action._point_head import PointHead_GetResult_Request  # noqa: F401
from control_msgs.action._point_head import PointHead_GetResult_Response  # noqa: F401
from control_msgs.action._point_head import PointHead_SendGoal_Event  # noqa: F401
from control_msgs.action._point_head import PointHead_SendGoal_Request  # noqa: F401
from control_msgs.action._point_head import PointHead_SendGoal_Response  # noqa: F401
from control_msgs.action._single_joint_position import SingleJointPosition  # noqa: F401
from control_msgs.action._single_joint_position import SingleJointPosition_GetResult_Event  # noqa: F401
from control_msgs.action._single_joint_position import SingleJointPosition_GetResult_Request  # noqa: F401
from control_msgs.action._single_joint_position import SingleJointPosition_GetResult_Response  # noqa: F401
from control_msgs.action._single_joint_position import SingleJointPosition_SendGoal_Event  # noqa: F401
from control_msgs.action._single_joint_position import SingleJointPosition_SendGoal_Request  # noqa: F401
from control_msgs.action._single_joint_position import SingleJointPosition_SendGoal_Response  # noqa: F401



from control_msgs.msg._admittance_controller_state import AdmittanceControllerState  # noqa: F401
from control_msgs.msg._battery_state_array import BatteryStateArray  # noqa: F401
from control_msgs.msg._dynamic_interface_group_values import DynamicInterfaceGroupValues  # noqa: F401
from control_msgs.msg._dynamic_interface_values import DynamicInterfaceValues  # noqa: F401
from control_msgs.msg._dynamic_joint_state import DynamicJointState  # noqa: F401
from control_msgs.msg._float64_values import Float64Values  # noqa: F401
from control_msgs.msg._gripper_command import GripperCommand  # noqa: F401
from control_msgs.msg._interface_value import InterfaceValue  # noqa: F401
from control_msgs.msg._joint_component_tolerance import JointComponentTolerance  # noqa: F401
from control_msgs.msg._joint_controller_state import JointControllerState  # noqa: F401
from control_msgs.msg._joint_jog import JointJog  # noqa: F401
from control_msgs.msg._joint_tolerance import JointTolerance  # noqa: F401
from control_msgs.msg._joint_trajectory_controller_state import JointTrajectoryControllerState  # noqa: F401
from control_msgs.msg._keys import Keys  # noqa: F401
from control_msgs.msg._mecanum_drive_controller_state import MecanumDriveControllerState  # noqa: F401
from control_msgs.msg._motion_argument import MotionArgument  # noqa: F401
from control_msgs.msg._motion_primitive import MotionPrimitive  # noqa: F401
from control_msgs.msg._motion_primitive_sequence import MotionPrimitiveSequence  # noqa: F401
from control_msgs.msg._multi_dof_command import MultiDOFCommand  # noqa: F401
from control_msgs.msg._multi_dof_state_stamped import MultiDOFStateStamped  # noqa: F401
from control_msgs.msg._pid_state import PidState  # noqa: F401
from control_msgs.msg._single_dof_state import SingleDOFState  # noqa: F401
from control_msgs.msg._single_dof_state_stamped import SingleDOFStateStamped  # noqa: F401
from control_msgs.msg._speed_scaling_factor import SpeedScalingFactor  # noqa: F401
from control_msgs.msg._steering_controller_status import SteeringControllerStatus  # noqa: F401
from control_msgs.msg._vda5050_safety_state import VDA5050SafetyState  # noqa: F401
